@@ -260,10 +260,8 @@ egg_toolbar_editor_class_init (EggToolbarEditorClass *klass)
 						       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 						       G_PARAM_CONSTRUCT));
 
-#if GTK_CHECK_VERSION (3, 20, 0)
   GtkWidgetClass *widget_class  = GTK_WIDGET_CLASS (klass);
   gtk_widget_class_set_css_name (widget_class, "EggToolbarEditor");
-#endif
 
   g_type_class_add_private (object_class, sizeof (EggToolbarEditorPrivate));
 }
@@ -511,8 +509,8 @@ editor_create_item_from_name (EggToolbarEditor *editor,
         icon = gtk_image_new_from_icon_name (icon_name,
 	                                     GTK_ICON_SIZE_LARGE_TOOLBAR);
       else
-        icon = gtk_image_new_from_stock (stock_id ? stock_id : GTK_STOCK_DND,
-                                         GTK_ICON_SIZE_LARGE_TOOLBAR);
+        icon = gtk_image_new_from_icon_name (stock_id ? stock_id : "gtk-dnd",
+                                             GTK_ICON_SIZE_LARGE_TOOLBAR);
 
       item_name = g_strdup (name);
       collate_key = g_utf8_collate_key (short_label, -1);
