@@ -24,6 +24,7 @@
 #include <math.h>
 
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 
 #include "ev-document-misc.h"
 
@@ -160,9 +161,11 @@ ev_document_misc_paint_one_page (cairo_t      *cr,
 	GtkStateFlags state = gtk_widget_get_state_flags (widget);
         GdkRGBA fg, bg, shade_bg;
 
+        gtk_style_context_save (context);
         gtk_style_context_get_background_color (context, state, &bg);
         gtk_style_context_get_color (context, state, &fg);
         gtk_style_context_get_color (context, state, &shade_bg);
+        gtk_style_context_restore (context);
         shade_bg.alpha *= 0.5;
 
 	gdk_cairo_set_source_rgba (cr, highlight ? &fg : &shade_bg);
@@ -394,29 +397,16 @@ ev_document_misc_invert_pixbuf (GdkPixbuf *pixbuf)
 }
 
 gdouble
-#if GTK_CHECK_VERSION (3, 22, 0)
 ev_document_misc_get_screen_dpi (GdkScreen *screen, GdkMonitor *monitor)
-#else
-ev_document_misc_get_screen_dpi (GdkScreen *screen, gint monitor)
-#endif
 {
 	gdouble dp, di;
-	gint sc_width, sc_height;
-
-	gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
-				 &sc_width, &sc_height);
 
 	/*diagonal in pixels*/
-	dp = hypot (sc_width, sc_height);
+	dp = hypot (WidthOfScreen (gdk_x11_screen_get_xscreen (screen)), HeightOfScreen (gdk_x11_screen_get_xscreen (screen)));
 
 	/*diagonal in inches*/
-#if GTK_CHECK_VERSION (3, 22, 0)
 	di = hypot (gdk_monitor_get_width_mm(monitor), gdk_monitor_get_height_mm (monitor)) / 25.4;
 	di /= gdk_monitor_get_scale_factor (monitor);
-#else
-	di = hypot (gdk_screen_get_width_mm(screen), gdk_screen_get_height_mm (screen)) / 25.4;
-	di /= gdk_screen_get_monitor_scale_factor(screen, monitor);
-#endif
 
 	return (dp / di);
 }
@@ -449,11 +439,7 @@ ev_document_misc_get_pointer_position (GtkWidget *widget,
                                        gint      *x,
                                        gint      *y)
 {
-#if GTK_CHECK_VERSION (3, 20, 0)
         GdkSeat *seat;
-#else
-        GdkDeviceManager *device_manager;
-#endif
         GdkDevice        *device_pointer;
         GdkRectangle      allocation;
 
@@ -465,13 +451,8 @@ ev_document_misc_get_pointer_position (GtkWidget *widget,
         if (!gtk_widget_get_realized (widget))
                 return;
 
-#if GTK_CHECK_VERSION (3, 20, 0)
         seat = gdk_display_get_default_seat (gtk_widget_get_display (widget));
         device_pointer = gdk_seat_get_pointer (seat);
-#else
-        device_manager = gdk_display_get_device_manager (gtk_widget_get_display (widget));
-        device_pointer = gdk_device_manager_get_client_pointer (device_manager);
-#endif
         gdk_window_get_device_position (gtk_widget_get_window (widget),
                                         device_pointer,
                                         x, y, NULL);
