@@ -366,7 +366,7 @@ ev_link_dest_class_init (EvLinkDestClass *ev_link_dest_class)
 					 PROP_CHANGE,
 					 g_param_spec_uint ("change",
 							    "Change",
-							    "Wether top, left, and zoom should be changed",
+							    "Whether top, left, and zoom should be changed",
 							    0,
 							    G_MAXUINT,
 							    0,
@@ -518,4 +518,4 @@ ev_link_dest_new_hlink(const gchar* hlink,gint page)
 	                                  "page",page,
 	                                  "type", EV_LINK_DEST_TYPE_HLINK,
 	                                  NULL));
-}
\ No newline at end of file
+}
