@@ -265,7 +265,7 @@ set_device_scale_on_surface (cairo_surface_t *surface,
 #ifdef HAVE_HIDPI_SUPPORT
 	cairo_surface_set_device_scale (surface, device_scale, device_scale);
 #else
-	g_return_if_fail (device_scale != 1);
+	g_return_if_fail (device_scale == 1);
 #endif
 }
 
@@ -296,8 +296,9 @@ copy_job_to_job_info (EvJobRender   *job_render,
 
 		job_info->selection_points = job_render->selection_points;
 		job_info->selection = cairo_surface_reference (job_render->selection);
-		job_info->selection_scale = job_render->scale;
-		set_device_scale_on_surface (job_info->selection, job_info->device_scale);
+		if (job_info->selection)
+			set_device_scale_on_surface (job_info->selection, job_info->device_scale);
+		job_info->selection_scale = job_render->scale * job_info->device_scale;
 		g_assert (job_info->selection_points.x1 >= 0);
 
 		job_info->selection_region_points = job_render->selection_points;
@@ -1089,9 +1090,10 @@ ev_pixbuf_cache_get_selection_surface (EvPixbufCache   *pixbuf_cache,
 					       old_points,
 					       job_info->selection_style,
 					       &text, &base);
-		set_device_scale_on_surface (job_info->selection, job_info->device_scale);
+		if (job_info->selection)
+			set_device_scale_on_surface (job_info->selection, job_info->device_scale);
 		job_info->selection_points = job_info->target_points;
-		job_info->selection_scale = scale;
+		job_info->selection_scale = scale * job_info->device_scale;
 		g_object_unref (rc);
 		ev_document_doc_mutex_unlock ();
 	}
