@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 
 #include "ev-view-presentation.h"
@@ -115,9 +116,6 @@ static void ev_view_presentation_set_cursor_for_location (EvViewPresentation *pv
 
 G_DEFINE_TYPE (EvViewPresentation, ev_view_presentation, GTK_TYPE_WIDGET)
 
-static GdkRGBA black = { 0., 0., 0., 1. };
-static GdkRGBA white = { 1., 1., 1., 1. };
-
 static void
 ev_view_presentation_set_normal (EvViewPresentation *pview)
 {
@@ -127,7 +125,8 @@ ev_view_presentation_set_normal (EvViewPresentation *pview)
 		return;
 
 	pview->state = EV_PRESENTATION_NORMAL;
-	gdk_window_set_background_rgba (gtk_widget_get_window (widget), &black);
+	gtk_style_context_remove_class (gtk_widget_get_style_context (widget),
+	                                "white-mode");
 	gtk_widget_queue_draw (widget);
 }
 
@@ -140,7 +139,8 @@ ev_view_presentation_set_black (EvViewPresentation *pview)
 		return;
 
 	pview->state = EV_PRESENTATION_BLACK;
-	gdk_window_set_background_rgba (gtk_widget_get_window (widget), &black);
+	gtk_style_context_remove_class (gtk_widget_get_style_context (widget),
+	                                "white-mode");
 	gtk_widget_queue_draw (widget);
 }
 
@@ -153,8 +153,8 @@ ev_view_presentation_set_white (EvViewPresentation *pview)
 		return;
 
 	pview->state = EV_PRESENTATION_WHITE;
-	gdk_window_set_background_rgba (gtk_widget_get_window (widget), &white);
-	gtk_widget_queue_draw (widget);
+	gtk_style_context_add_class (gtk_widget_get_style_context (widget),
+	                             "white-mode");
 }
 
 static void
@@ -283,11 +283,28 @@ ev_view_presentation_transition_animation_frame (EvViewPresentation *pview,
 	gtk_widget_queue_draw (GTK_WIDGET (pview));
 }
 
+static cairo_surface_t *
+get_surface_from_job (EvViewPresentation *pview,
+		      EvJob              *job)
+{
+	cairo_surface_t *surface;
+
+	if (!job)
+		return NULL;
+
+	surface = EV_JOB_RENDER(job)->surface;
+	if (!surface)
+		return NULL;
+
+	return surface;
+}
+
 static void
 ev_view_presentation_animation_start (EvViewPresentation *pview,
 				      gint                new_page)
 {
 	EvTransitionEffect *effect = NULL;
+	EvJob              *job;
 	cairo_surface_t    *surface;
 	gint                jump;
 
@@ -311,11 +328,12 @@ ev_view_presentation_animation_start (EvViewPresentation *pview,
 
 	jump = new_page - pview->current_page;
 	if (jump == -1)
-		surface = pview->prev_job ? EV_JOB_RENDER (pview->prev_job)->surface : NULL;
+		job = pview->prev_job;
 	else if (jump == 1)
-		surface = pview->next_job ? EV_JOB_RENDER (pview->next_job)->surface : NULL;
+		job = pview->next_job;
 	else
-		surface = NULL;
+		job = NULL;
+	surface = get_surface_from_job (pview, job);
 	if (surface)
 		ev_transition_animation_set_dest_surface (pview->animation, surface);
 
@@ -342,7 +360,7 @@ job_finished_cb (EvJob              *job,
 
 	if (pview->animation) {
 		ev_transition_animation_set_dest_surface (pview->animation,
-							  job_render->surface);
+							  get_surface_from_job (pview, job));
 	} else {
 		ev_view_presentation_transition_start (pview);
 		gtk_widget_queue_draw (GTK_WIDGET (pview));
@@ -489,7 +507,10 @@ ev_view_presentation_update_current_page (EvViewPresentation *pview,
 		}
 	}
 
-	pview->current_page = page;
+	if (pview->current_page != page) {
+		pview->current_page = page;
+		g_object_notify (G_OBJECT (pview), "current-page");
+	}
 
 	if (pview->page_cache)
 		ev_page_cache_set_page_range (pview->page_cache, page, page);
@@ -505,6 +526,21 @@ ev_view_presentation_update_current_page (EvViewPresentation *pview,
 		gtk_widget_queue_draw (GTK_WIDGET (pview));
 }
 
+static void
+ev_view_presentation_set_current_page (EvViewPresentation *pview,
+                                       guint               page)
+{
+	if (pview->current_page == page)
+		return;
+
+	if (!gtk_widget_get_realized (GTK_WIDGET (pview))) {
+		pview->current_page = page;
+		g_object_notify (G_OBJECT (pview), "current-page");
+	} else {
+		ev_view_presentation_update_current_page (pview, page);
+	}
+}
+
 void
 ev_view_presentation_next_page (EvViewPresentation *pview)
 {
@@ -650,9 +686,9 @@ ev_view_presentation_goto_window_create (EvViewPresentation *pview)
 	GtkWindow *toplevel, *goto_window;
 
 	toplevel = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (pview)));
-	goto_window = GTK_WINDOW (pview->goto_window);
 
 	if (pview->goto_window) {
+	    goto_window = GTK_WINDOW (pview->goto_window);
 		if (gtk_window_has_group (toplevel))
 			gtk_window_group_add_window (gtk_window_get_group (toplevel), goto_window);
 		else if (gtk_window_has_group (goto_window))
@@ -662,6 +698,7 @@ ev_view_presentation_goto_window_create (EvViewPresentation *pview)
 	}
 
 	pview->goto_window = gtk_window_new (GTK_WINDOW_POPUP);
+	goto_window = GTK_WINDOW (pview->goto_window);
 	gtk_window_set_screen (goto_window, gtk_widget_get_screen (GTK_WIDGET (pview)));
 
 	if (gtk_window_has_group (toplevel))
@@ -720,16 +757,12 @@ ev_view_presentation_goto_window_send_key_event (EvViewPresentation *pview,
 {
 	GdkEventKey *new_event;
 	GdkScreen   *screen;
-	gint         sc_width;
-	gint         sc_height;
 
 	/* Move goto window off screen */
 	screen = gtk_widget_get_screen (GTK_WIDGET (pview));
-
-	gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
-				 &sc_width, &sc_height);
-
-	gtk_window_move (GTK_WINDOW (pview->goto_window), sc_width + 1, sc_height + 1);
+	gtk_window_move (GTK_WINDOW (pview->goto_window),
+			 WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) + 1,
+			 HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) + 1);
 	gtk_widget_show (pview->goto_window);
 
 	new_event = (GdkEventKey *) gdk_event_copy (event);
@@ -1029,6 +1062,13 @@ ev_view_presentation_draw (GtkWidget *widget,
 	cairo_surface_t    *surface;
 	cairo_rectangle_int_t clip_rect;
 	GdkRectangle *area = &clip_rect;
+	GtkStyleContext    *context;
+
+	context = gtk_widget_get_style_context (GTK_WIDGET (pview));
+	gtk_render_background (context, cr,
+	                       0, 0,
+	                       gtk_widget_get_allocated_width (widget),
+	                       gtk_widget_get_allocated_height (widget));
 
 	if (!gdk_cairo_get_clip_rectangle (cr, &clip_rect))
 		return FALSE;
@@ -1061,7 +1101,7 @@ ev_view_presentation_draw (GtkWidget *widget,
 		return TRUE;
 	}
 
-	surface = pview->curr_job ? EV_JOB_RENDER (pview->curr_job)->surface : NULL;
+	surface = get_surface_from_job (pview, pview->curr_job);
 	if (surface) {
 		ev_view_presentation_update_current_surface (pview, surface);
 	} else if (pview->current_surface) {
@@ -1209,29 +1249,25 @@ ev_view_presentation_motion_notify_event (GtkWidget      *widget,
 	return FALSE;
 }
 
+static void
+ev_view_presentation_update_monitor_geometry (EvViewPresentation *pview)
+{
+	GdkDisplay          *display = gtk_widget_get_display (GTK_WIDGET (pview));
+	GdkRectangle        monitor;
+	GdkMonitor          *monitor_num;
+
+	monitor_num = gdk_display_get_monitor_at_window (display, gtk_widget_get_window (GTK_WIDGET (pview)));
+	gdk_monitor_get_geometry (monitor_num, &monitor);
+	pview->monitor_width = monitor.width;
+	pview->monitor_height = monitor.height;
+}
+
 static gboolean
 init_presentation (GtkWidget *widget)
 {
 	EvViewPresentation *pview = EV_VIEW_PRESENTATION (widget);
-#if GTK_CHECK_VERSION (3, 22, 0)
-	GdkDisplay         *display = gtk_widget_get_display (widget);
-	GdkRectangle        monitor;
-	GdkMonitor         *monitor_num;
-#else
-	GdkScreen          *screen = gtk_widget_get_screen (widget);
-	GdkRectangle        monitor;
-	gint                monitor_num;
-#endif
 
-#if GTK_CHECK_VERSION (3, 22, 0)
-	monitor_num = gdk_display_get_monitor_at_window (display, gtk_widget_get_window (widget));
-	gdk_monitor_get_geometry (monitor_num, &monitor);
-#else
-	monitor_num = gdk_screen_get_monitor_at_window (screen, gtk_widget_get_window (widget));
-	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
-#endif
-	pview->monitor_width = monitor.width;
-	pview->monitor_height = monitor.height;
+	ev_view_presentation_update_monitor_geometry (pview);
 
 	ev_view_presentation_update_current_page (pview, pview->current_page);
 	ev_view_presentation_hide_cursor_timeout_start (pview);
@@ -1355,7 +1391,7 @@ ev_view_presentation_set_property (GObject      *object,
 		pview->enable_animations = EV_IS_DOCUMENT_TRANSITION (pview->document);
 		break;
 	case PROP_CURRENT_PAGE:
-		pview->current_page = g_value_get_uint (value);
+		ev_view_presentation_set_current_page (pview, g_value_get_uint (value));
 		break;
 	case PROP_ROTATION:
                 ev_view_presentation_set_rotation (pview, g_value_get_uint (value));
@@ -1377,6 +1413,9 @@ ev_view_presentation_get_property (GObject    *object,
         EvViewPresentation *pview = EV_VIEW_PRESENTATION (object);
 
         switch (prop_id) {
+        case PROP_CURRENT_PAGE:
+                g_value_set_uint (value, pview->current_page);
+                break;
         case PROP_ROTATION:
                 g_value_set_uint (value, ev_view_presentation_get_rotation (pview));
                 break;
@@ -1385,6 +1424,14 @@ ev_view_presentation_get_property (GObject    *object,
         }
 }
 
+	static void
+ev_view_presentation_notify_scale_factor (EvViewPresentation *pview)
+{
+	ev_view_presentation_update_monitor_geometry (pview);
+	ev_view_presentation_reset_jobs (pview);
+	ev_view_presentation_update_current_page (pview, pview->current_page);
+}
+
 static GObject *
 ev_view_presentation_constructor (GType                  type,
 				  guint                  n_construct_properties,
@@ -1404,6 +1451,9 @@ ev_view_presentation_constructor (GType                  type,
 		ev_page_cache_set_flags (pview->page_cache, EV_PAGE_DATA_INCLUDE_LINKS);
 	}
 
+	g_signal_connect (object, "notify::scale-factor",
+			  G_CALLBACK (ev_view_presentation_notify_scale_factor), NULL);
+
 	return object;
 }
 
@@ -1426,6 +1476,8 @@ ev_view_presentation_class_init (EvViewPresentationClass *klass)
 	widget_class->motion_notify_event = ev_view_presentation_motion_notify_event;
 	widget_class->scroll_event = ev_view_presentation_scroll_event;
 
+	gtk_widget_class_set_css_name (widget_class, "evpresentationview");
+
 	gobject_class->dispose = ev_view_presentation_dispose;
 
 	gobject_class->constructor = ev_view_presentation_constructor;
@@ -1447,7 +1499,7 @@ ev_view_presentation_class_init (EvViewPresentationClass *klass)
 							    "The current page",
 							    0, G_MAXUINT, 0,
 							    G_PARAM_WRITABLE |
-							    G_PARAM_CONSTRUCT_ONLY));
+							    G_PARAM_CONSTRUCT));
 	g_object_class_install_property (gobject_class,
 					 PROP_ROTATION,
 					 g_param_spec_uint ("rotation",
@@ -1527,25 +1579,8 @@ ev_view_presentation_class_init (EvViewPresentationClass *klass)
 static void
 ev_view_presentation_init (EvViewPresentation *pview)
 {
-	static gsize initialization_value = 0;
-
 	gtk_widget_set_can_focus (GTK_WIDGET (pview), TRUE);
-         pview->is_constructing = TRUE;
-
-	if (g_once_init_enter (&initialization_value)) {
-		GtkCssProvider *provider;
-
-		provider = gtk_css_provider_new ();
-		gtk_css_provider_load_from_data (provider,
-						 "EvViewPresentation {\n"
-						 " background-color: black; }",
-						 -1, NULL);
-		gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-							   GTK_STYLE_PROVIDER (provider),
-							   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-		g_object_unref (provider);
-		g_once_init_leave (&initialization_value, 1);
-	}
+	pview->is_constructing = TRUE;
 }
 
 GtkWidget *
