@@ -71,20 +71,13 @@ static gdouble
 get_screen_dpi (EvPreviewerWindow *window)
 {
 	GdkScreen  *screen;
-#if GTK_CHECK_VERSION (3, 22, 0)
 	GdkMonitor *monitor;
 	GdkDisplay *display;
-#else
-	gint        monitor;
-#endif
 
 	screen = gtk_window_get_screen (GTK_WINDOW (window));
-#if GTK_CHECK_VERSION (3, 22, 0)
 	display = gdk_screen_get_display (screen);
 	monitor = gdk_display_get_primary_monitor (display);
-#else
-	monitor = gdk_screen_get_primary_monitor (screen);
-#endif
+
 	return ev_document_misc_get_screen_dpi (screen, monitor);
 }
 
@@ -145,6 +138,14 @@ ev_previewer_window_zoom_out (GtkAction         *action,
 	ev_view_zoom_out (window->view);
 }
 
+static void
+ev_previewer_window_zoom_reset (GtkAction         *action,
+			      EvPreviewerWindow *window)
+{
+	ev_document_model_set_sizing_mode (window->model, EV_SIZING_FREE);
+	ev_view_zoom_reset (window->view);
+}
+
 static void
 ev_previewer_window_zoom_fit_page (GtkToggleAction   *action,
 				   EvPreviewerWindow *window)
@@ -276,50 +277,55 @@ ev_previewer_window_print (GtkAction         *action,
 #endif
 
 static const GtkActionEntry action_entries[] = {
-	{ "FileCloseWindow", GTK_STOCK_CLOSE, NULL, "<control>W",
+	{ "FileCloseWindow", "window-close", N_("_Close"), "<control>W",
 	  NULL,
 	  G_CALLBACK (ev_previewer_window_close) },
-	{ "GoPreviousPage", GTK_STOCK_GO_UP, N_("_Previous Page"), "<control>Page_Up",
+	{ "GoPreviousPage", "go-up", N_("_Previous Page"), "<control>Page_Up",
           N_("Go to the previous page"),
           G_CALLBACK (ev_previewer_window_previous_page) },
-        { "GoNextPage", GTK_STOCK_GO_DOWN, N_("_Next Page"), "<control>Page_Down",
+        { "GoNextPage", "go-down", N_("_Next Page"), "<control>Page_Down",
           N_("Go to the next page"),
           G_CALLBACK (ev_previewer_window_next_page) },
-        { "ViewZoomIn", GTK_STOCK_ZOOM_IN, NULL, "<control>plus",
+        { "ViewZoomIn", "zoom-in", N_("Zoom _In"), "<control>plus",
           N_("Enlarge the document"),
           G_CALLBACK (ev_previewer_window_zoom_in) },
-        { "ViewZoomOut", GTK_STOCK_ZOOM_OUT, NULL, "<control>minus",
+        { "ViewZoomOut", "zoom-out", N_("Zoom _Out"), "<control>minus",
           N_("Shrink the document"),
           G_CALLBACK (ev_previewer_window_zoom_out) },
+        { "ViewZoomReset", "zoom-original", NULL, "<control>0",
+          N_("Reset zoom to 100\%"),
+          G_CALLBACK (ev_previewer_window_zoom_reset) },
 #if GTKUNIXPRINT_ENABLED
 	/* translators: Print document currently shown in the Print Preview window */
-	{ "PreviewPrint", GTK_STOCK_PRINT, N_("Print"), NULL,
+	{ "PreviewPrint", "document-print", N_("Print"), NULL,
 	  N_("Print this document"),
 	  G_CALLBACK (ev_previewer_window_print) }
 #endif
 };
 
 static const GtkActionEntry accel_entries[] = {
-	{ "p", GTK_STOCK_GO_UP, "", "p", NULL,
+	{ "p", "go-up", "", "p", NULL,
 	  G_CALLBACK (ev_previewer_window_previous_page) },
-	{ "n", GTK_STOCK_GO_DOWN, "", "n", NULL,
+	{ "n", "go-down", "", "n", NULL,
 	  G_CALLBACK (ev_previewer_window_next_page) },
-	{ "Plus", GTK_STOCK_ZOOM_IN, NULL, "plus", NULL,
+	{ "Plus", "zoom-in", NULL, "plus", NULL,
 	  G_CALLBACK (ev_previewer_window_zoom_in) },
-	{ "CtrlEqual", GTK_STOCK_ZOOM_IN, NULL, "<control>equal", NULL,
+	{ "CtrlEqual", "zoom-in", NULL, "<control>equal", NULL,
 	  G_CALLBACK (ev_previewer_window_zoom_in) },
-	{ "Equal", GTK_STOCK_ZOOM_IN, NULL, "equal", NULL,
+	{ "Equal", "zoom-in", NULL, "equal", NULL,
 	  G_CALLBACK (ev_previewer_window_zoom_in) },
-	{ "Minus", GTK_STOCK_ZOOM_OUT, NULL, "minus", NULL,
+	{ "Minus", "zoom-out", NULL, "minus", NULL,
 	  G_CALLBACK (ev_previewer_window_zoom_out) },
-	{ "KpPlus", GTK_STOCK_ZOOM_IN, NULL, "KP_Add", NULL,
+	{ "KpPlus", "zoom-in", NULL, "KP_Add", NULL,
 	  G_CALLBACK (ev_previewer_window_zoom_in) },
-	{ "KpMinus", GTK_STOCK_ZOOM_OUT, NULL, "KP_Subtract", NULL,
+	{ "KpMinus", "zoom-out", NULL, "KP_Subtract", NULL,
 	  G_CALLBACK (ev_previewer_window_zoom_out) },
-	{ "CtrlKpPlus", GTK_STOCK_ZOOM_IN, NULL, "<control>KP_Add", NULL,
+	{ "CtrlKpPlus", "zoom-in", NULL, "<control>KP_Add", NULL,
 	  G_CALLBACK (ev_previewer_window_zoom_in) },
-	{ "CtrlKpMinus", GTK_STOCK_ZOOM_OUT, NULL, "<control>KP_Subtract", NULL,
+	{ "CtrlKpMinus", "zoom-out", NULL, "<control>KP_Subtract", NULL,
 	  G_CALLBACK (ev_previewer_window_zoom_out) },
+	{ "CtrlKpZero", "zoom-original", NULL, "<control>KP_0", NULL,
+	  G_CALLBACK (ev_previewer_window_zoom_reset) },
 	{ "FocusPageSelector", NULL, "", "<control>l", NULL,
 	  G_CALLBACK (ev_previewer_window_focus_page_selector) }
 
@@ -386,7 +392,6 @@ ev_previewer_window_set_document (EvPreviewerWindow *window,
 	g_signal_connect (model, "notify::sizing-mode",
 			  G_CALLBACK (view_sizing_mode_changed),
 			  window);
-	ev_view_set_loading (window->view, FALSE);
 	gtk_action_group_set_sensitive (window->action_group, TRUE);
 	gtk_action_group_set_sensitive (window->accels_group, TRUE);
 }
@@ -463,15 +468,14 @@ ev_previewer_window_dispose (GObject *object)
 	G_OBJECT_CLASS (ev_previewer_window_parent_class)->dispose (object);
 }
 
-static gchar*
-data_dir (void)
-{
-	return g_strdup (ATRILDATADIR);
-}
-
 static void
 ev_previewer_window_init (EvPreviewerWindow *window)
 {
+	GtkStyleContext *context;
+
+	context = gtk_widget_get_style_context (GTK_WIDGET (window));
+	gtk_style_context_add_class (context, "atril-previewer-window");
+
 	gtk_window_set_default_size (GTK_WINDOW (window), 600, 600);
 }
 
@@ -503,7 +507,6 @@ ev_previewer_window_constructor (GType                  type,
 	GtkWidget         *toolbar;
 	GtkAction         *action;
 	GError            *error = NULL;
-	gchar             *datadir, *ui_path;
 	gdouble            dpi;
 
 	object = G_OBJECT_CLASS (ev_previewer_window_parent_class)->constructor (type,
@@ -556,14 +559,9 @@ ev_previewer_window_constructor (GType                  type,
 					    window->accels_group, 1);
 	gtk_window_add_accel_group (GTK_WINDOW (window),
 				    gtk_ui_manager_get_accel_group (window->ui_manager));
-	datadir = data_dir ();
-	ui_path = g_build_filename (datadir, "atril-previewer-ui.xml", NULL);
-	if (!gtk_ui_manager_add_ui_from_file (window->ui_manager, ui_path, &error)) {
-		g_warning ("Failed to load ui from atril-previewer-ui.xml: %s", error->message);
-		g_error_free (error);
-	}
-	g_free (ui_path);
-	g_free (datadir);
+
+	gtk_ui_manager_add_ui_from_resource (window->ui_manager, "/org/mate/atril/previewer/ui/previewer.xml", &error);
+	g_assert_no_error (error);
 
 	/* GTKUIManager connects actions accels only for menu items,
 	 * but not for tool items. See bug #612972.
@@ -592,7 +590,6 @@ ev_previewer_window_constructor (GType                  type,
 				 window, 0);
 	ev_view_set_model (window->view, window->model);
 	ev_document_model_set_continuous (window->model, FALSE);
-	ev_view_set_loading (window->view, TRUE);
 
 	gtk_container_add (GTK_CONTAINER (window->swindow), GTK_WIDGET (window->view));
 	gtk_widget_show (GTK_WIDGET (window->view));
