@@ -1,7 +1,7 @@
 /* this file is part of atril, a mate document viewer
  *
  *  Copyright (C) 2004 Martin Kretzschmar
- *  Copyright © 2010 Christian Persch
+ *  Copyright © 2010, 2012 Christian Persch
  *
  *  Author:
  *    Martin Kretzschmar <martink@gnome.org>
@@ -32,8 +32,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 
-#include "totem-scrsaver.h"
-
 #include "eggsmclient.h"
 
 #include "ev-application.h"
@@ -41,36 +39,31 @@
 #include "ev-stock-icons.h"
 
 #ifdef ENABLE_DBUS
+#include "ev-gdbus-generated.h"
 #include "ev-media-player-keys.h"
 #endif /* ENABLE_DBUS */
 
 struct _EvApplication {
-	GObject base_instance;
+	GtkApplication base_instance;
 
 	gchar *uri;
 
 	gchar *dot_dir;
-	gchar *data_dir;
 
 #ifdef ENABLE_DBUS
-	GDBusConnection *connection;
-        guint registration_id;
+	EvAtrilApplication *skeleton;
 	EvMediaPlayerKeys *keys;
 	gboolean doc_registered;
 #endif
 
-	TotemScrsaver *scr_saver;
-
 	EggSMClient *smclient;
 };
 
 struct _EvApplicationClass {
-	GObjectClass base_class;
+	GtkApplicationClass base_class;
 };
 
-static EvApplication *instance;
-
-G_DEFINE_TYPE (EvApplication, ev_application, G_TYPE_OBJECT);
+G_DEFINE_TYPE (EvApplication, ev_application, GTK_TYPE_APPLICATION)
 
 #ifdef ENABLE_DBUS
 #define APPLICATION_DBUS_OBJECT_PATH "/org/mate/atril/Atril"
@@ -100,20 +93,21 @@ static void ev_application_open_uri_in_window (EvApplication  *application,
 					       guint           timestamp);
 
 /**
- * ev_application_get_instance:
+ * ev_application_new:
  *
- * Checks for #EvApplication instance, if it doesn't exist it does create it.
+ * Creates a new #EvApplication instance.
  *
- * Returns: an instance of the #EvApplication data.
+ * Returns: (transfer full): a newly created #EvApplication
  */
 EvApplication *
-ev_application_get_instance (void)
+ev_application_new (void)
 {
-	if (!instance) {
-		instance = EV_APPLICATION (g_object_new (EV_TYPE_APPLICATION, NULL));
-	}
+  const GApplicationFlags flags = G_APPLICATION_NON_UNIQUE;
 
-	return instance;
+  return g_object_new (EV_TYPE_APPLICATION,
+                       "application-id", NULL,
+                       "flags", flags,
+                       NULL);
 }
 
 /* Session */
@@ -156,10 +150,10 @@ smclient_save_state_cb (EggSMClient   *client,
 }
 
 static void
-smclient_quit_cb (EggSMClient   *client,
-		  EvApplication *application)
+smclient_quit_cb (EggSMClient  *client,
+                  GApplication *application)
 {
-	ev_application_shutdown (application);
+        g_application_quit (application);
 }
 
 static void
@@ -284,42 +278,28 @@ ev_spawn (const char     *uri,
 		g_object_unref (ctx);
 	}
 	if (error != NULL) {
-		g_warning ("Error launching atril %s: %s\n", uri, error->message);
+		g_printerr ("Error launching atril %s: %s\n", uri, error->message);
 		g_error_free (error);
 	}
 
 	g_free (cmdline);
 }
 
-static GList *
-ev_application_get_windows (EvApplication *application)
-{
-	GList *l, *toplevels;
-	GList *windows = NULL;
-
-	toplevels = gtk_window_list_toplevels ();
-
-	for (l = toplevels; l != NULL; l = l->next) {
-		if (EV_IS_WINDOW (l->data)) {
-			windows = g_list_append (windows, l->data);
-		}
-	}
-
-	g_list_free (toplevels);
-
-	return windows;
-}
-
 static EvWindow *
 ev_application_get_empty_window (EvApplication *application,
 				 GdkScreen     *screen)
 {
 	EvWindow *empty_window = NULL;
-	GList    *windows = ev_application_get_windows (application);
-	GList    *l;
+	GList    *windows, *l;
 
+        windows = gtk_application_get_windows (GTK_APPLICATION (application));
 	for (l = windows; l != NULL; l = l->next) {
-		EvWindow *window = EV_WINDOW (l->data);
+		EvWindow *window;
+
+                if (!EV_IS_WINDOW (l->data))
+                          continue;
+
+                window = EV_WINDOW (l->data);
 
 		if (ev_window_is_empty (window) &&
 		    gtk_window_get_screen (GTK_WINDOW (window)) == screen) {
@@ -328,8 +308,6 @@ ev_application_get_empty_window (EvApplication *application,
 		}
 	}
 
-	g_list_free (windows);
-
 	return empty_window;
 }
 
@@ -368,18 +346,19 @@ on_reload_cb (GObject      *source_object,
 	GVariant        *value;
 	GError          *error = NULL;
 
+	g_application_release (g_application_get_default ());
+
 	value = g_dbus_connection_call_finish (connection, res, &error);
-	if (!value) {
-		g_warning ("Failed to Reload: %s", error->message);
+	if (value != NULL) {
+                g_variant_unref (value);
+        } else {
+		g_printerr ("Failed to Reload: %s\n", error->message);
 		g_error_free (error);
 	}
-	g_variant_unref (value);
 
 	/* We did not open a window, so manually clear the startup
 	 * notification. */
 	gdk_notify_startup_complete ();
-
-	ev_application_shutdown (EV_APP);
 }
 
 static void
@@ -395,9 +374,11 @@ on_register_uri_cb (GObject      *source_object,
 	GVariantBuilder    builder;
 	GError            *error = NULL;
 
+	g_application_release (G_APPLICATION (application));
+
 	value = g_dbus_connection_call_finish (connection, res, &error);
 	if (!value) {
-		g_warning ("Error registering document: %s\n", error->message);
+		g_printerr ("Error registering document: %s\n", error->message);
 		g_error_free (error);
 
 		_ev_application_open_uri_at_dest (application,
@@ -487,6 +468,7 @@ on_register_uri_cb (GObject      *source_object,
 				NULL,
 				on_reload_cb,
 				NULL);
+        g_application_hold (G_APPLICATION (application));
 	g_variant_unref (value);
 	ev_register_doc_data_free (data);
 }
@@ -515,23 +497,24 @@ ev_application_register_uri (EvApplication  *application,
 {
 	EvRegisterDocData *data;
 
-	if (!application->connection)
+	if (!application->skeleton)
 		return;
 
 	if (application->doc_registered) {
 		/* Already registered, reload */
 		GList *windows, *l;
 
-		windows = ev_application_get_windows (application);
+		windows = gtk_application_get_windows (GTK_APPLICATION (application));
 		for (l = windows; l != NULL; l = g_list_next (l)) {
-			EvWindow *ev_window = EV_WINDOW (l->data);
+                        if (!EV_IS_WINDOW (l->data))
+                                continue;
 
-			ev_application_open_uri_in_window (application, uri, ev_window,
+			ev_application_open_uri_in_window (application, uri,
+                                                           EV_WINDOW (l->data),
 							   screen, dest, mode,
 							   search_string,
 							   timestamp);
 		}
-		g_list_free (windows);
 
 		return;
 	}
@@ -544,7 +527,7 @@ ev_application_register_uri (EvApplication  *application,
 	data->search_string = search_string ? g_strdup (search_string) : NULL;
 	data->timestamp = timestamp;
 
-        g_dbus_connection_call (application->connection,
+        g_dbus_connection_call (g_application_get_dbus_connection (G_APPLICATION (application)),
 				ATRIL_DAEMON_SERVICE,
 				ATRIL_DAEMON_OBJECT_PATH,
 				ATRIL_DAEMON_INTERFACE,
@@ -556,6 +539,8 @@ ev_application_register_uri (EvApplication  *application,
 				NULL,
 				on_register_uri_cb,
 				data);
+
+        g_application_hold (G_APPLICATION (application));
 }
 
 static void
@@ -572,7 +557,7 @@ ev_application_unregister_uri (EvApplication *application,
 	 * so it's safe to use the sync api
 	 */
         value = g_dbus_connection_call_sync (
-		application->connection,
+		g_application_get_dbus_connection (G_APPLICATION (application)),
 		ATRIL_DAEMON_SERVICE,
 		ATRIL_DAEMON_OBJECT_PATH,
 		ATRIL_DAEMON_INTERFACE,
@@ -584,7 +569,7 @@ ev_application_unregister_uri (EvApplication *application,
 		NULL,
 		&error);
         if (value == NULL) {
-		g_warning ("Error unregistering document: %s\n", error->message);
+		g_printerr ("Error unregistering document: %s\n", error->message);
 		g_error_free (error);
 	} else {
                 g_variant_unref (value);
@@ -604,6 +589,9 @@ ev_application_open_uri_in_window (EvApplication  *application,
 {
 	GdkWindow *gdk_window;
 
+	if (uri == NULL)
+	        uri = application->uri;
+
 	if (screen) {
 		ev_stock_icons_set_screen (screen);
 		gtk_window_set_screen (GTK_WINDOW (ev_window), screen);
@@ -717,110 +705,92 @@ ev_application_open_window (EvApplication *application,
 }
 
 #ifdef ENABLE_DBUS
-static void
-method_call_cb (GDBusConnection       *connection,
-                const gchar           *sender,
-                const gchar           *object_path,
-                const gchar           *interface_name,
-                const gchar           *method_name,
-                GVariant              *parameters,
-                GDBusMethodInvocation *invocation,
-                gpointer               user_data)
+static gboolean
+handle_get_window_list_cb (EvAtrilApplication    *object,
+                           GDBusMethodInvocation *invocation,
+                           EvApplication         *application)
 {
-        EvApplication   *application = EV_APPLICATION (user_data);
-	GList           *windows, *l;
-        guint            timestamp;
-        GVariantIter    *iter;
+        GList     *windows, *l;
+        GPtrArray *paths;
+
+        paths = g_ptr_array_new ();
+
+        windows = gtk_application_get_windows (GTK_APPLICATION (application));
+        for (l = windows; l; l = g_list_next (l)) {
+                if (!EV_IS_WINDOW (l->data))
+                        continue;
+
+                g_ptr_array_add (paths, (gpointer) ev_window_get_dbus_object_path (EV_WINDOW (l->data)));
+        }
+
+        g_ptr_array_add (paths, NULL);
+        ev_atril_application_complete_get_window_list (object, invocation,
+                                                        (const char * const *) paths->pdata);
+
+        g_ptr_array_free (paths, TRUE);
+
+        return TRUE;
+}
+
+static gboolean
+handle_reload_cb (EvAtrilApplication   *object,
+                  GDBusMethodInvocation *invocation,
+                  GVariant              *args,
+                  guint                  timestamp,
+                  EvApplication         *application)
+{
+        GList           *windows, *l;
+        GVariantIter     iter;
         const gchar     *key;
         GVariant        *value;
         GdkDisplay      *display = NULL;
-	EvLinkDest      *dest = NULL;
-	EvWindowRunMode  mode = EV_WINDOW_MODE_NORMAL;
-	const gchar     *search_string = NULL;
-	GdkScreen       *screen = NULL;
+        EvLinkDest      *dest = NULL;
+        EvWindowRunMode  mode = EV_WINDOW_MODE_NORMAL;
+        const gchar     *search_string = NULL;
+        GdkScreen       *screen = NULL;
 
-	if (g_strcmp0 (method_name, "Reload") == 0) {
-		g_variant_get (parameters, "(a{sv}u)", &iter, &timestamp);
+        g_variant_iter_init (&iter, args);
 
-		while (g_variant_iter_loop (iter, "{&sv}", &key, &value)) {
-			if (strcmp (key, "display") == 0 && g_variant_classify (value) == G_VARIANT_CLASS_STRING) {
-				display = ev_display_open_if_needed (g_variant_get_string (value, NULL));
-			} else if (strcmp (key, "mode") == 0 && g_variant_classify (value) == G_VARIANT_CLASS_UINT32) {
-			mode = g_variant_get_uint32 (value);
-			} else if (strcmp (key, "page-label") == 0 && g_variant_classify (value) == G_VARIANT_CLASS_STRING) {
-				dest = ev_link_dest_new_page_label (g_variant_get_string (value, NULL));
-			} else if (strcmp (key, "named-dest") == 0 && g_variant_classify (value) == G_VARIANT_CLASS_STRING) {
-				dest = ev_link_dest_new_named (g_variant_get_string (value, NULL));
-			} else if (strcmp (key, "page-index") == 0 && g_variant_classify (value) == G_VARIANT_CLASS_UINT32) {
-				dest = ev_link_dest_new_page (g_variant_get_uint32 (value));
-			} else if (strcmp (key, "find-string") == 0 && g_variant_classify (value) == G_VARIANT_CLASS_STRING) {
-				search_string = g_variant_get_string (value, NULL);
-			}
-		}
-		g_variant_iter_free (iter);
+        while (g_variant_iter_loop (&iter, "{&sv}", &key, &value)) {
+                if (strcmp (key, "display") == 0 && g_variant_classify (value) == G_VARIANT_CLASS_STRING) {
+                        display = ev_display_open_if_needed (g_variant_get_string (value, NULL));
+                } else if (strcmp (key, "mode") == 0 && g_variant_classify (value) == G_VARIANT_CLASS_UINT32) {
+                        mode = g_variant_get_uint32 (value);
+                } else if (strcmp (key, "page-label") == 0 && g_variant_classify (value) == G_VARIANT_CLASS_STRING) {
+                        dest = ev_link_dest_new_page_label (g_variant_get_string (value, NULL));
+                } else if (strcmp (key, "named-dest") == 0 && g_variant_classify (value) == G_VARIANT_CLASS_STRING) {
+                        dest = ev_link_dest_new_named (g_variant_get_string (value, NULL));
+                } else if (strcmp (key, "page-index") == 0 && g_variant_classify (value) == G_VARIANT_CLASS_UINT32) {
+                        dest = ev_link_dest_new_page (g_variant_get_uint32 (value));
+                } else if (strcmp (key, "find-string") == 0 && g_variant_classify (value) == G_VARIANT_CLASS_STRING) {
+                        search_string = g_variant_get_string (value, NULL);
+                }
+        }
 
-		if (display != NULL)
-			screen = gdk_display_get_default_screen (display);
-		else
-			screen = gdk_screen_get_default ();
+        if (display != NULL)
+                screen = gdk_display_get_default_screen (display);
+        else
+                screen = gdk_screen_get_default ();
 
-		windows = ev_application_get_windows (application);
-		for (l = windows; l != NULL; l = g_list_next (l)) {
-			EvWindow *ev_window = EV_WINDOW (l->data);
+        windows = gtk_application_get_windows (GTK_APPLICATION ((application)));
+        for (l = windows; l != NULL; l = g_list_next (l)) {
+                if (!EV_IS_WINDOW (l->data))
+                        continue;
 
-			ev_application_open_uri_in_window (application, application->uri,
-							   ev_window,
-							   screen, dest, mode,
-							   search_string,
-							   timestamp);
-		}
-		g_list_free (windows);
+                ev_application_open_uri_in_window (application, NULL,
+                                                   EV_WINDOW (l->data),
+                                                   screen, dest, mode,
+                                                   search_string,
+                                                   timestamp);
+        }
 
-		if (dest)
-			g_object_unref (dest);
+        if (dest)
+                g_object_unref (dest);
 
-		g_dbus_method_invocation_return_value (invocation, g_variant_new ("()"));
-	} else if (g_strcmp0 (method_name, "GetWindowList") == 0) {
-		GList          *windows = ev_application_get_windows (application);
-		GVariantBuilder builder;
-		GList	       *l;
+        ev_atril_application_complete_reload (object, invocation);
 
-		g_variant_builder_init (&builder, G_VARIANT_TYPE ("(ao)"));
-		g_variant_builder_open (&builder, G_VARIANT_TYPE ("ao"));
-
-		for (l = windows; l; l = g_list_next (l)) {
-			EvWindow *window = (EvWindow *)l->data;
-
-			g_variant_builder_add (&builder, "o", ev_window_get_dbus_object_path (window));
-		}
-
-		g_variant_builder_close (&builder);
-		g_list_free (windows);
-
-		g_dbus_method_invocation_return_value (invocation, g_variant_builder_end (&builder));
-	}
+        return TRUE;
 }
-
-static const char introspection_xml[] =
-        "<node>"
-          "<interface name='org.mate.atril.Application'>"
-            "<method name='Reload'>"
-              "<arg type='a{sv}' name='args' direction='in'/>"
-              "<arg type='u' name='timestamp' direction='in'/>"
-            "</method>"
-            "<method name='GetWindowList'>"
-              "<arg type='ao' name='window_list' direction='out'/>"
-            "</method>"
-          "</interface>"
-        "</node>";
-
-static const GDBusInterfaceVTable interface_vtable = {
-	method_call_cb,
-	NULL,
-	NULL
-};
-
-static GDBusNodeInfo *introspection_data;
 #endif /* ENABLE_DBUS */
 
 void
@@ -894,9 +864,11 @@ static void ev_application_accel_map_load(EvApplication* application)
 	g_free(accel_map_file);
 }
 
-void
-ev_application_shutdown (EvApplication *application)
+static void
+ev_application_shutdown (GApplication *gapplication)
 {
+        EvApplication *application = EV_APPLICATION (gapplication);
+
 	if (application->uri) {
 #ifdef ENABLE_DBUS
 		ev_application_unregister_uri (application,
@@ -908,49 +880,104 @@ ev_application_shutdown (EvApplication *application)
 
 	ev_application_accel_map_save (application);
 
-	g_object_unref (application->scr_saver);
-	application->scr_saver = NULL;
-
-#ifdef ENABLE_DBUS
-	if (application->keys) {
-		g_object_unref (application->keys);
-		application->keys = NULL;
-	}
-        if (application->registration_id != 0) {
-                g_dbus_connection_unregister_object (application->connection,
-                                                     application->registration_id);
-                application->registration_id = 0;
-        }
-        if (application->connection != NULL) {
-                g_object_unref (application->connection);
-                application->connection = NULL;
-        }
-	if (introspection_data) {
-		g_dbus_node_info_ref (introspection_data);
-		introspection_data = NULL;
-	}
-#endif /* ENABLE_DBUS */
-
         g_free (application->dot_dir);
         application->dot_dir = NULL;
-        g_free (application->data_dir);
-        application->data_dir = NULL;
 
-	g_object_unref (application);
-        instance = NULL;
-
-	gtk_main_quit ();
+        G_APPLICATION_CLASS (ev_application_parent_class)->shutdown (gapplication);
 }
 
+static void
+ev_application_activate (GApplication *gapplication)
+{
+        EvApplication *application = EV_APPLICATION (gapplication);
+        GList *windows, *l;
+
+        windows = gtk_application_get_windows (GTK_APPLICATION (application));
+        for (l = windows; l != NULL; l = l->next) {
+                if (!EV_IS_WINDOW (l->data))
+                        continue;
+
+                gtk_window_present (GTK_WINDOW (l->data));
+        }
+}
+
+#ifdef ENABLE_DBUS
+static gboolean
+ev_application_dbus_register (GApplication    *gapplication,
+                              GDBusConnection *connection,
+                              const gchar     *object_path,
+                              GError         **error)
+{
+        EvApplication *application = EV_APPLICATION (gapplication);
+        EvAtrilApplication *skeleton;
+
+        if (!G_APPLICATION_CLASS (ev_application_parent_class)->dbus_register (gapplication,
+                                                                               connection,
+                                                                               object_path,
+                                                                               error))
+                return FALSE;
+
+        skeleton = ev_atril_application_skeleton_new ();
+        if (!g_dbus_interface_skeleton_export (G_DBUS_INTERFACE_SKELETON (skeleton),
+                                               connection,
+                                               APPLICATION_DBUS_OBJECT_PATH,
+                                               error)) {
+                g_object_unref (skeleton);
+
+                return FALSE;
+        }
+
+        application->skeleton = skeleton;
+        g_signal_connect (skeleton, "handle-get-window-list",
+                          G_CALLBACK (handle_get_window_list_cb),
+                          application);
+        g_signal_connect (skeleton, "handle-reload",
+                          G_CALLBACK (handle_reload_cb),
+                          application);
+        application->keys = ev_media_player_keys_new ();
+
+        return TRUE;
+}
+
+static void
+ev_application_dbus_unregister (GApplication    *gapplication,
+                                GDBusConnection *connection,
+                                const gchar     *object_path)
+{
+        EvApplication *application = EV_APPLICATION (gapplication);
+
+        if (application->keys) {
+                g_object_unref (application->keys);
+                application->keys = NULL;
+        }
+        if (application->skeleton != NULL) {
+                g_dbus_interface_skeleton_unexport (G_DBUS_INTERFACE_SKELETON (application->skeleton));
+                g_object_unref (application->skeleton);
+                application->skeleton = NULL;
+        }
+
+        G_APPLICATION_CLASS (ev_application_parent_class)->dbus_unregister (gapplication,
+                                                                            connection,
+                                                                            object_path);
+}
+
+#endif /* ENABLE_DBUS */
+
 static void ev_application_class_init(EvApplicationClass* ev_application_class)
 {
-	/* Nothing */
+        GApplicationClass *g_application_class = G_APPLICATION_CLASS (ev_application_class);
+
+        g_application_class->activate = ev_application_activate;
+        g_application_class->shutdown = ev_application_shutdown;
+
+#ifdef ENABLE_DBUS
+        g_application_class->dbus_register = ev_application_dbus_register;
+        g_application_class->dbus_unregister = ev_application_dbus_unregister;
+#endif
 }
 
 static void ev_application_init(EvApplication* ev_application)
 {
-	GError* error = NULL;
-
 	userdir = g_getenv("MATE22_USER_DIR");
 
 	if (userdir)
@@ -962,86 +989,41 @@ static void ev_application_init(EvApplication* ev_application)
 		ev_application->dot_dir = g_build_filename(g_get_user_config_dir(), "atril", NULL);
 	}
 
-	ev_application->data_dir = g_strdup (ATRILDATADIR);
-
 	ev_application_init_session (ev_application);
 
 	ev_application_accel_map_load (ev_application);
-
-#ifdef ENABLE_DBUS
-        ev_application->connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
-        if (ev_application->connection != NULL) {
-                introspection_data = g_dbus_node_info_new_for_xml (introspection_xml, NULL);
-                g_assert (introspection_data != NULL);
-
-                ev_application->registration_id =
-                    g_dbus_connection_register_object (ev_application->connection,
-                                                       APPLICATION_DBUS_OBJECT_PATH,
-                                                       introspection_data->interfaces[0],
-                                                       &interface_vtable,
-                                                       ev_application, NULL,
-                                                       &error);
-                if (ev_application->registration_id == 0) {
-                        g_printerr ("Failed to register bus object: %s\n", error->message);
-                        g_error_free (error);
-                }
-        } else {
-                g_printerr ("Failed to get bus connection: %s\n", error->message);
-                g_error_free (error);
-        }
-
-	ev_application->keys = ev_media_player_keys_new ();
-#endif /* ENABLE_DBUS */
-
-	ev_application->scr_saver = totem_scrsaver_new ();
-	g_object_set (ev_application->scr_saver,
-		      "reason", _("Running in presentation mode"),
-		      NULL);
-}
-
-GDBusConnection *
-ev_application_get_dbus_connection (EvApplication *application)
-{
-#ifdef ENABLE_DBUS
-	return application->connection;
-#else
-	return NULL;
-#endif
 }
 
 gboolean
 ev_application_has_window (EvApplication *application)
 {
-	GList    *l, *toplevels;
-	gboolean  retval = FALSE;
+	GList *l, *windows;
 
-	toplevels = gtk_window_list_toplevels ();
+	windows = gtk_application_get_windows (GTK_APPLICATION (application));
+	for (l = windows; l != NULL; l = l->next) {
+		if (!EV_IS_WINDOW (l->data))
+                        continue;
 
-	for (l = toplevels; l != NULL && !retval; l = l->next) {
-		if (EV_IS_WINDOW (l->data))
-			retval = TRUE;
+                return TRUE;
 	}
 
-	g_list_free (toplevels);
-
-	return retval;
+	return FALSE;
 }
 
 guint
 ev_application_get_n_windows (EvApplication *application)
 {
-	GList *l, *toplevels;
-	guint  retval = 0;
+        GList *l, *windows;
+        guint retval = 0;
 
-	toplevels = gtk_window_list_toplevels ();
+        windows = gtk_application_get_windows (GTK_APPLICATION (application));
+        for (l = windows; l != NULL && !retval; l = l->next) {
+                if (!EV_IS_WINDOW (l->data))
+                        continue;
 
-	for (l = toplevels; l != NULL; l = l->next) {
-		if (EV_IS_WINDOW (l->data))
-			retval++;
+                retval++;
 	}
 
-	g_list_free (toplevels);
-
 	return retval;
 }
 
@@ -1069,18 +1051,6 @@ ev_application_get_media_keys (EvApplication *application)
 #endif /* ENABLE_DBUS */
 }
 
-void
-ev_application_screensaver_enable (EvApplication *application)
-{
-	totem_scrsaver_enable (application->scr_saver);
-}
-
-void
-ev_application_screensaver_disable (EvApplication *application)
-{
-	totem_scrsaver_disable (application->scr_saver);
-}
-
 const gchar *
 ev_application_get_dot_dir (EvApplication *application,
                             gboolean create)
@@ -1090,9 +1060,3 @@ ev_application_get_dot_dir (EvApplication *application,
 
 	return application->dot_dir;
 }
-
-const gchar *
-ev_application_get_data_dir (EvApplication   *application)
-{
-	return application->data_dir;
-}
